==> bundlesbeyond-1.3.2%2B1.21.9%2Bfabric-sources.jar: o7410/bundlesbeyond/ScrollMode.java <==
package o7410.bundlesbeyond;

import com.mojang.serialization.Codec;
import net.minecraft.class_2561;
import net.minecraft.class_2568;
import net.minecraft.class_3542;

public enum ScrollMode implements class_3542 {
    HOLD_FOR_VERTICAL("Hold key to scroll vertically", "hold_for_vertical", "Hold for vertical"),
    HOLD_FOR_HORIZONTAL("Hold key to scroll horizontally", "hold_for_horizontal", "Hold for horizontal"),
    HORIZONTAL("Horizontal, press key for vertical", "horizontal", "Horizontal"),
    VERTICAL("Vertical, press key for horizontal", "vertical", "Vertical"),
    VANILLA("Vanilla scrolling", "vanilla", "Vanilla");

    public static final Codec<ScrollMode> CODEC = class_3542.method_28140(ScrollMode::values);

    public final String description;
    public final String id;
    public final String shortName;

    ScrollMode(String description, String id, String shortName) {
        this.id = id;
        this.description = description;
        this.shortName = shortName;
    }

    public class_2561 getDescriptionText() {
        return class_2561.method_43470(this.description);
    }

    public class_2561 getShortNameText() {
        return class_2561.method_43470(this.shortName).method_27694(style -> style.method_10949(
                //? if <1.21.8 {
                /*new HoverEvent(HoverEvent.Action.SHOW_TEXT, this.getDescriptionText())
                *///?} else {
                new class_2568.class_10613(this.getDescriptionText())
                //?}
        ));
    }

    @Override
    public String method_15434() {
        return this.id;
    }

    @Override
    public String toString() {
        return this.id;
    }
}

==> bundlesbeyond-1.4.0%2B1.21.3%2Bfabric-sources.jar: o7410/bundlesbeyond/ScrollMode.java <==
package o7410.bundlesbeyond;

import com.mojang.serialization.Codec;
import net.minecraft.class_2561;
import net.minecraft.class_2568;
import net.minecraft.class_3542;

public enum ScrollMode implements class_3542 {
    HOLD_FOR_VERTICAL("Hold key to scroll vertically", "hold_for_vertical", "Hold for vertical"),
    HOLD_FOR_HORIZONTAL("Hold key to scroll horizontally", "hold_for_horizontal", "Hold for horizontal"),
    HORIZONTAL("Horizontal, press key for vertical", "horizontal", "Horizontal"),
    VERTICAL("Vertical, press key for horizontal", "vertical", "Vertical"),
    VANILLA("Vanilla scrolling", "vanilla", "Vanilla");

    public static final Codec<ScrollMode> CODEC = class_3542.method_28140(ScrollMode::values);

    public final String description;
    public final String id;
    public final String shortName;

    ScrollMode(String description, String id, String shortName) {
        this.id = id;
        this.description = description;
        this.shortName = shortName;
    }

    public class_2561 getDescriptionText() {
        return class_2561.method_43470(this.description);
    }

    public class_2561 getShortNameText() {
        return class_2561.method_43470(this.shortName).method_27694(style -> style.method_10949(
                //? if <1.21.8 {
                new class_2568(class_2568.class_5247.field_24342, this.getDescriptionText())
                //?} else {
                /*new HoverEvent.ShowText(this.getDescriptionText())
                *///?}
        ));
    }

    @Override
    public String method_15434() {
        return this.id;
    }

    @Override
    public String toString() {
        return this.id;
    }
}
